@@ -1,5 +1,5 @@
 /* *
- * Copyright (C) 2005 Mekensleep
+ * Copyright (C) 2005, 2006 Mekensleep
  *
  *	Mekensleep
  *	24 rue vieille du temple
@@ -22,6 +22,7 @@
  *
  * Authors:
  *  Loic Dachary <loic@gnu.org>
+ *  Cedric Pinson <cpinson@freesheep.org>
  */
 
 #include <time.h>
@@ -39,6 +40,7 @@
 #define VARIANT_7STUD 3
 #define VARIANTS_COUNT 4
 
+enum lobby_tab_state g_lobby_tab_state = none;
 static GladeXML* s_lobby_xml = 0;
 static GtkWidget*	s_lobby_window = 0;
 static GtkLabel*	s_players_label = 0;
@@ -68,6 +70,9 @@ static GtkWidget*	s_clock_label = 0;
 
 static GdkPixbuf*	pixbuf_table_my = 0;
 
+static int		s_lobby_shown = 0;
+static GtkLayout* s_screen = 0;
+
 static void clear_stores(void) {
   int i;
   for(i = 0; i < VARIANTS_COUNT; i++) {
@@ -76,14 +81,16 @@ static void clear_stores(void) {
   gtk_list_store_clear(s_players_store);
 }
 
-static void	close_lobby(void)
+static void	close_lobby()
 {
-  gtk_widget_hide(s_lobby_window);
-  gtk_widget_hide(s_table_info_window);
-  gtk_widget_hide(s_lobby_tabs_window);
-  gtk_widget_hide(s_cashier_button_window);
-  gtk_widget_hide(s_clock_window);
-  clear_stores();
+	if (s_screen == NULL)
+		return;
+	gtk_widget_hide(s_lobby_window);
+	gtk_widget_hide(s_table_info_window);
+	gtk_widget_hide(s_lobby_tabs_window);
+	gtk_widget_hide(s_cashier_button_window);
+	gtk_widget_hide(s_clock_window);
+	clear_stores();
 }
 
 static void	on_go_to_clicked(GtkWidget *widget, gpointer user_data)
@@ -153,38 +160,62 @@ static void	on_lobby_list_treeview_selection_changed(GtkTreeSelection *treeselec
     g_warning("treeview_selection: unable to find active row");
 }
 
+void tournament_on_table_toggled(GtkWidget *widget, gpointer user_data);
 static void	on_table_toggled(GtkWidget *widget, gpointer user_data)
 {
-  (void) user_data;
-
-  if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
-    const char* name = gtk_widget_get_name(widget);
-    if(!strcmp(name, "holdem")) {
-      gtk_notebook_set_current_page(s_notebook, VARIANT_HOLDEM);
-    } else if(!strcmp(name, "omaha")) {
-      gtk_notebook_set_current_page(s_notebook, VARIANT_OMAHA);
-    } else if(!strcmp(name, "omaha8")) {
-      gtk_notebook_set_current_page(s_notebook, VARIANT_OMAHA8);
-    } else if(!strcmp(name, "7stud")) {
-      gtk_notebook_set_current_page(s_notebook, VARIANT_7STUD);
+  if (g_lobby_tab_state == tournament)
+    {
+      tournament_on_table_toggled(widget, user_data);
+    }
+  else if (g_lobby_tab_state == lobby)
+    {
+      (void) user_data;
+      
+      if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+	const char* name = gtk_widget_get_name(widget);
+	if(!strcmp(name, "holdem")) {
+	  gtk_notebook_set_current_page(s_notebook, VARIANT_HOLDEM);
+	} else if(!strcmp(name, "omaha")) {
+	  gtk_notebook_set_current_page(s_notebook, VARIANT_OMAHA);
+	} else if(!strcmp(name, "omaha8")) {
+	  gtk_notebook_set_current_page(s_notebook, VARIANT_OMAHA8);
+	} else if(!strcmp(name, "7stud")) {
+	  gtk_notebook_set_current_page(s_notebook, VARIANT_7STUD);
+	}
+	set_string("lobby");
+	set_string("refresh");
+	set_string(name);
+	flush_io_channel();
+      }
+    }
+  else
+    {
+      g_critical("g_lobby_tab_state is %i\n", g_lobby_tab_state);
     }
-    set_string("lobby");
-    set_string("refresh");
-    set_string(name);
-    flush_io_channel();
-  }
 }
 
+void tournament_on_tourney_toggled(GtkWidget *widget, gpointer user_data);
 static void	on_tourney_toggled(GtkWidget *widget, gpointer user_data)
 {
-  (void) user_data;
-
-  if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
-    set_string("lobby");
-    set_string("quit");
-    set_string(gtk_widget_get_name(widget));
-    flush_io_channel();
-  }
+  if (g_lobby_tab_state == tournament)
+    {
+      tournament_on_tourney_toggled(widget, user_data);
+    }
+  else if (g_lobby_tab_state == lobby)
+    {
+      (void) user_data;
+      
+      if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
+	set_string("lobby");
+	set_string("quit");
+	set_string(gtk_widget_get_name(widget));
+	flush_io_channel();
+      }
+    }
+  else
+    {
+      g_critical("g_lobby_tab_state is %i\n", g_lobby_tab_state);
+    }
 }
 
 static void	on_all_radio_clicked(GtkWidget* widget, gpointer data)
@@ -200,7 +231,7 @@ static void	on_all_radio_clicked(GtkWidget* widget, gpointer data)
   }
 }
 
-static void	on_play_money_radio_clicked(GtkWidget* widget, gpointer data)
+static void	on_money_one_radio_clicked(GtkWidget* widget, gpointer data)
 {
   (void) data;
 
@@ -208,12 +239,12 @@ static void	on_play_money_radio_clicked(GtkWidget* widget, gpointer data)
     clear_stores();
     set_string("lobby");
     set_string("refresh");
-    set_string("play");
+    set_string("money_one");
     flush_io_channel();
   }
 }
 
-static void	on_custom_money_radio_clicked(GtkWidget* widget, gpointer data)
+static void	on_money_two_radio_clicked(GtkWidget* widget, gpointer data)
 {
   (void) data;
 
@@ -221,7 +252,7 @@ static void	on_custom_money_radio_clicked(GtkWidget* widget, gpointer data)
     clear_stores();
     set_string("lobby");
     set_string("refresh");
-    set_string("custom");
+    set_string("money_two");
     flush_io_channel();
   }
 }
@@ -240,6 +271,7 @@ static void on_cashier_button_pressed(GtkButton* button, gpointer data)
 int	handle_lobby(GladeXML* g_lobby_xml, GladeXML* g_table_info_xml, GladeXML* g_lobby_tabs_xml, GladeXML* g_cashier_button_xml, GladeXML* g_clock_xml, GtkLayout* screen, int init)
 {
   static int s_selected_table = 0;
+	s_screen = screen;
 
   if(init) {
     int i;
@@ -283,20 +315,22 @@ int	handle_lobby(GladeXML* g_lobby_xml, GladeXML* g_table_info_xml, GladeXML* g_
         gchar* filename;
 
         filename = glade_xml_relative_file(g_lobby_xml, "table_bullet_my.png");
-        pixbuf_table_my = gdk_pixbuf_new_from_file(filename, &error);
-        if(pixbuf_table_my == NULL) {
-          GtkIconTheme* theme = gtk_icon_theme_get_default();
-          error = 0;
-          pixbuf_table_my = gtk_icon_theme_load_icon(theme, 
-                                               "stock_book_open",
-                                               16,
-                                               0,
-                                               &error);
-          if (!pixbuf_table_my) {
-            g_warning ("Couldn't load icon: %s", error->message);
+        if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
+          pixbuf_table_my = gdk_pixbuf_new_from_file(filename, &error);
+          if(pixbuf_table_my == NULL) {
+            GtkIconTheme* theme = gtk_icon_theme_get_default();
+            error = 0;
+            pixbuf_table_my = gtk_icon_theme_load_icon(theme, 
+                                                       "stock_book_open",
+                                                       16,
+                                                       0,
+                                                       &error);
+            if (!pixbuf_table_my) {
+              g_warning ("Couldn't load icon: %s", error->message);
+            }
           }
         }
-
+        g_free(filename);
       }
 #define SET_COLUMN(TITLE, INDEX) \
       { \
@@ -328,8 +362,8 @@ int	handle_lobby(GladeXML* g_lobby_xml, GladeXML* g_table_info_xml, GladeXML* g_
     s_players_label = GTK_LABEL(gui_get_widget(g_lobby_xml, "players_label"));
     s_tables_label = GTK_LABEL(gui_get_widget(g_lobby_xml, "tables_label"));
     GUI_BRANCH(g_lobby_xml, on_all_radio_clicked);
-    GUI_BRANCH(g_lobby_xml, on_play_money_radio_clicked);
-    GUI_BRANCH(g_lobby_xml, on_custom_money_radio_clicked);
+    GUI_BRANCH(g_lobby_xml, on_money_one_radio_clicked);
+    GUI_BRANCH(g_lobby_xml, on_money_two_radio_clicked);
 
     s_table_info_window = gui_get_widget(g_table_info_xml, "table_info_window");
     g_assert(s_table_info_window);
@@ -389,48 +423,54 @@ int	handle_lobby(GladeXML* g_lobby_xml, GladeXML* g_table_info_xml, GladeXML* g_
 
   char* tag = get_string();
   if(!strcmp(tag, "show")) {
-    /*
-     * calculate windows position
-     */
-    int	screen_width = gui_width(screen);
-    int	screen_height = gui_height(screen);
-
-    int	top_left_x = (screen_width - 900) / 2;
-    int	top_left_y = (screen_height - 500) / 2;
-
-    {
-      static position_t position;
-      position.x = top_left_x + 350;
-      position.y = top_left_y;
-      gui_place(s_lobby_window, &position, screen);
-    }
-
-    {
-      static position_t position;
-      position.x = top_left_x;
-      position.y = top_left_y;
-      gui_place(s_table_info_window, &position, screen);
-    }
-
-    {
-      static position_t position;
-      position.x = 0;
-      position.y = 33;
-      gui_place(s_lobby_tabs_window, &position, screen);
-    }
-
+    g_lobby_tab_state = lobby;
     {
       char* label = get_string();
       gtk_button_set_label(s_cashier_button, label);
       g_free(label);
     }
-    {
-      static position_t position;
-      position.x = top_left_x;
-      position.y = top_left_y + 400;
-      gui_place(s_cashier_button_window, &position, screen);
-    }
 
+    if (screen != NULL || s_lobby_shown == 0)
+      {
+				/*
+				 * calculate windows position
+				 */
+				int	screen_width = gui_width(screen);
+				int	screen_height = gui_height(screen);
+	
+				int	top_left_x = (screen_width - 1000) / 2;
+				int	top_left_y = (screen_height - 450) / 2;
+	
+				{
+					static position_t position;
+					position.x = screen_width - 610;
+					position.y = top_left_y;
+					gui_place(s_lobby_window, &position, screen);
+				}
+	
+				{
+					static position_t position;
+					position.x = top_left_x;
+					position.y = top_left_y;
+					gui_place(s_table_info_window, &position, screen);
+				}
+	
+				{
+					static position_t position;
+					position.x = 0;
+					position.y = 33;
+					gui_place(s_lobby_tabs_window, &position, screen);
+				}
+	
+				{
+					static position_t position;
+					position.x = top_left_x;
+					position.y = top_left_y + 435;
+					gui_place(s_cashier_button_window, &position, screen);
+				}
+				s_lobby_shown = 1;
+      }
+		
     {
       gui_bottom_right(s_clock_window, screen);
     }
@@ -455,28 +495,44 @@ int	handle_lobby(GladeXML* g_lobby_xml, GladeXML* g_table_info_xml, GladeXML* g_
     }
 
     {
-      char* custom_money = get_string();
+      char* currency_serial = get_string();
       char* button;
       GtkWidget* radio;
-      if(!strcmp(custom_money, "y")) {
-        button = "custom_money_radio";
-      } else if(!strcmp(custom_money, "y")) {
-        button = "play_money_radio";
+      if(!strcmp(currency_serial, "money_two")) {
+        button = "money_two_radio";
+      } else if(!strcmp(currency_serial, "money_one")) {
+        button = "money_one_radio";
       } else {
         button = "all_radio";
       }
 
+      {
+        //moneyone
+        GtkWidget* sl = gui_get_widget(g_lobby_xml, "money_one_radio");
+        char* label = get_string();
+        gtk_button_set_label(GTK_BUTTON(sl), label);
+        g_free(label);
+      }
+
+      {
+        //moneytwo
+        GtkWidget* sl = gui_get_widget(g_lobby_xml, "money_two_radio");
+        char* label = get_string();
+        gtk_button_set_label(GTK_BUTTON(sl), label);
+        g_free(label);
+      }
+
       s_disable_buttons = 1;
       radio = gui_get_widget(s_lobby_xml, button);
       g_assert(radio);
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio), TRUE);
       s_disable_buttons = 0;
 
-      g_free(custom_money);
+      g_free(currency_serial);
     }
   } else if(!strcmp(tag, "hide")) {
+    g_lobby_tab_state = none;
     close_lobby();
-
   } else if(!strcmp(tag, "info")) {
     char* players_count = get_string();
     char* tables_count = get_string();
@@ -546,7 +602,7 @@ int	handle_lobby(GladeXML* g_lobby_xml, GladeXML* g_table_info_xml, GladeXML* g_
   } else if(!strcmp(tag, "players")) {
     int players_count = get_int();
     int i;
-    gtk_label_set_text(s_go_to_label, "Go To");
+    gtk_label_set_text(s_go_to_label, "GO TO TABLE");
     gtk_widget_set_sensitive(GTK_WIDGET(s_go_to_button), TRUE);
     gtk_list_store_clear(s_players_store);
     for(i = 0; i < players_count; i++) {
