@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2004, 2005 Mekensleep
+# Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
 # 24 rue vieille du temple
@@ -22,14 +22,14 @@
 #
 # Authors:
 #  Loic Dachary <loic@gnu.org>
-#  Henry Precheur <henry@precheur.org>
+#  Henry Precheur <henry@precheur.org> (2004)
 #
 import sys
 sys.path.insert(0, "..")
 
 from os import popen
 from os.path import exists
-from string import split
+from string import split, rstrip
 from random import randint
 from traceback import print_exc
 
@@ -38,7 +38,6 @@ from twisted.python import components
 from twisted.persisted import sob
 from twisted.internet import reactor, error
 
-from pokerengine.pokerchips import PokerChips
 from pokerengine.pokertournament import *
 
 from pokernetwork import pokernetworkconfig
@@ -85,6 +84,21 @@ class StringGenerator:
             input.close()
         return self.pool.pop()
 
+class NoteGenerator:
+
+    def __init__(self, command):
+        self.command = command
+        print "NoteGenerator " + self.command
+        self.pool = []
+
+    def getNote(self):
+        while len(self.pool) == 0:
+            input = popen(self.command)
+            self.pool = map(lambda string: rstrip(string).split('\t'), input.readlines())
+            input.close()
+            print "NoteGenerator " + str(self.pool)
+        return self.pool.pop()
+
 class PokerBot:
 
     def __init__(self, factory):
@@ -97,7 +111,7 @@ class PokerBot:
             if join_info['tournament']:
                 protocol.sendPacket(PacketPokerTourneySelect(string = join_info["name"]))
             else:
-                protocol.sendPacket(PacketPokerTableSelect(string = "play"))
+                protocol.sendPacket(PacketPokerTableSelect(string = "1"))
             self.state = STATE_SEARCHING
             self.factory.can_disconnect = True
             
@@ -114,6 +128,10 @@ class PokerBot:
         elif packet.type == PACKET_POKER_BATCH_MODE:
             self.state = STATE_BATCH
             
+        elif packet.type == PACKET_SERIAL:
+            protocol.sendPacket(PacketPokerCashIn(serial = packet.serial,
+                                                  note = PokerBotFactory.note_generator.getNote()))
+            
         elif packet.type == PACKET_POKER_STREAM_MODE:
             self.state = STATE_RUNNING
             if self.batch_end_action:
@@ -317,10 +335,10 @@ class PokerBot:
             protocol.sendPacket(PacketPokerCall(game_id = game.id,
                                                 serial = serial))
         elif desired_action == "raise":
-            minimum = PokerChips(game.chips_values)
+            (min_bet, max_bet, to_call) = game.betLimits(serial)
             protocol.sendPacket(PacketPokerRaise(game_id = game.id,
                                                  serial = serial,
-                                                 amount = minimum.chips))
+                                                 amount = min_bet * 2))
         else:
             print "=> unexpected actions = %s" % actions
         self.factory.can_disconnect = True
@@ -349,6 +367,7 @@ class PokerBotProtocol(PokerClientProtocol):
 class PokerBotFactory(PokerClientFactory):
 
     string_generator = None
+    note_generator = None
 
     def __init__(self, *args, **kwargs):
         PokerClientFactory.__init__(self, *args, **kwargs)
@@ -365,6 +384,7 @@ class PokerBotFactory(PokerClientFactory):
         self.reconnect_delay = settings.headerGet("/settings/@reconnect_delay")
         if self.reconnect_delay:
             self.reconnect_delay = tuple(map(lambda x: int(x), split(self.reconnect_delay, ",")))
+        self.currency = settings.headerGetInt("/settings/currency")
         self.verbose = settings.headerGetInt("/settings/@verbose")
         self.bot = None
         self.went_broke = False
@@ -379,6 +399,7 @@ class PokerBotFactory(PokerClientFactory):
         protocol._poll = False
         protocol.registerHandler(True, PACKET_BOOTSTRAP, pokerbot._handleConnection)
         protocol.registerHandler(True, PACKET_ERROR, pokerbot._handleConnection)
+        protocol.registerHandler('outbound', PACKET_SERIAL, pokerbot._handleConnection)
         protocol.registerHandler(True, PACKET_POKER_BATCH_MODE, pokerbot._handleConnection)
         protocol.registerHandler(True, PACKET_POKER_STREAM_MODE, pokerbot._handleConnection)
         protocol.registerHandler(True, PACKET_POKER_ERROR, pokerbot._handleConnection)
@@ -436,7 +457,7 @@ class Bots(service.MultiService):
     def check(self):
         if self.verbose > 1:
             print "%d bots currently active" % len(self.services)
-        if len(self.services) <= 0:
+        if len(self.services) <= 0 and reactor.running:
             reactor.callLater(0, reactor.stop)
 
 def Application(name, uid=None, gid=None):
@@ -481,6 +502,7 @@ def makeApplication(argv):
     settings.load(configuration)
 
     PokerBotFactory.string_generator = StringGenerator(settings.headerGet("/settings/@name_prefix"))
+    PokerBotFactory.note_generator = NoteGenerator(settings.headerGet("/settings/currency"))
 
     ( host, port ) = split(settings.headerGet("/settings/servers"), ":")
     port = int(port)
@@ -489,7 +511,7 @@ def makeApplication(argv):
     bots.verbose = settings.headerGetInt("/settings/@verbose")
     services = service.IServiceCollection(bots)
     services.setSettings(settings)
-    
+
     for table in settings.headerGetProperties("/settings/table"):
         for i in range(0, int(table["count"])):
             table['tournament'] = False
