@@ -230,8 +230,12 @@ class PokerChildBrowser(PokerChild):
 
     def spawn(self):
         if platform.system() == "Windows":
-            win32api.ShellExecute(0, "", self.commandLine[1], "", "", 1)
-            return True
+			try:
+				win32api.ShellExecute(0, None, self.commandLine[1], None, None, 1)
+			except:
+				target = win32api.RegQueryValue(win32con.HKEY_CLASSES_ROOT, "HTTP\shell\open\command")
+				raise Exception("*CRITICAL*: failed to start browser at: %s" % target)
+			return True
         else:
             return PokerChild.spawn(self)
 
@@ -278,6 +282,8 @@ class PokerRsync(PokerChild, ProcessProtocol):
                                                                            rsync)
         if platform.system() == "Windows":
             self.rsync = map(lambda x: '"' + x + '"', self.rsync)
+            import re
+            self.rsync = map(lambda x: re.sub(r'(.):\\(.*)', r'/cygdrive/\1/\2', x), self.rsync)
         return True
 
     def spawn(self):
