@@ -317,7 +317,7 @@ class PokerClientFactory(UGAMEClientFactory):
         pass
 
     def failedUpgrade(self, logs, reason):
-        pass
+        raise UserWarning, "upgrade failed reason:%s logs:%s" % (str(reason), str(logs))
 
     def needUpgrade(self, version):
         pass
@@ -1390,7 +1390,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
     def protocolInvalid(self, server, client):
         self.schedulePacket(PacketProtocolError(message = "Upgrade the client from\nhttp://mekensleep.org/\nServer version is %s\nClient version is %s" % ( server, client ) ))
         self.publishAllPackets()
-        UGAMEClientProtocol.protocolInvalid(self)
+        UGAMEClientProtocol.protocolInvalid(self, server, client)
 
     def publishDelay(self, delay):
         if self.factory.verbose > 2: self.message("publishDelay: %f delay" % delay)
@@ -1404,17 +1404,20 @@ class PokerClientProtocol(UGAMEClientProtocol):
         self.publish_packets.append(packet)
         if not self._poll:
             self.publishPacket()
+        else:
+            self.publishPacketTriggerTimer()
             
     def unschedulePackets(self, predicate):
         self.publish_packets = filter(lambda packet: not predicate(packet), self.publish_packets)
+        if self._poll:
+            self.publishPacketTriggerTimer()
         
     def publishPackets(self):
         if not self._poll:
             return
-        
+
         delay = 0.01
-        packets_len = len(self.publish_packets)
-        if packets_len > 0:
+        if len(self.publish_packets) > 0:
             #
             # If time has not come, make sure we are called at a later time
             # to reconsider the situation
@@ -1423,19 +1426,23 @@ class PokerClientProtocol(UGAMEClientProtocol):
             if wait_for > 0:
                 if self.factory.verbose > 2:
                     self.message("publishPackets: %f before next packet is sent" % wait_for)
-                    delay = wait_for
-                    self.block()
+                delay = wait_for
+                self.block()
             else:
                 self.publishPacket()
-                if packets_len > 0:
+                if len(self.publish_packets) > 0:
                     self.block()
                 else:
                     self.unblock()
         else:
             self.unblock()
             
+        self.publishPacketTriggerTimer(delay)
+
+    def publishPacketTriggerTimer(self, delay = 0.01):
         if not self.publish_timer or not self.publish_timer.active():
-            self.publish_timer = reactor.callLater(delay, self.publishPackets)
+            if len(self.publish_packets) > 0:
+                self.publish_timer = reactor.callLater(delay, self.publishPackets)
 
     def publishPacket(self):
         packet = self.publish_packets[0]
