@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2004, 2005 Mekensleep
+# Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
 # 24 rue vieille du temple
@@ -31,7 +31,6 @@ from twisted.internet import defer
 
 from pokernetwork.pokerpackets import *
 from random import choice, uniform, randint
-from pokerengine.pokerchips import PokerChips
 from time import time
 
 class PokerAnimationPlayer:
@@ -82,6 +81,13 @@ class PokerAnimationPlayer:
         designed to be called after a suspend but will also work
         otherwise."""
         self.is_suspended = False
+
+    def setPlayerDelay(self, delay):
+        if not hasattr(self, 'table'): return
+        game = self.table.game
+        if self.table.scheduler and self.table.scheduler.protocol:
+            protocol = self.table.scheduler.protocol
+            protocol.setPlayerDelay(game, self.serial, delay)
         
     def callLater(self, delay, function, *args, **kwargs):
         self.callLaterTagged(function.__name__, delay, function, *args, **kwargs)
@@ -102,7 +108,7 @@ class PokerAnimationPlayer:
         self.last_end_round=time()
 
     def playerArrive(self):
-        print "player arrive run stand animation"
+        #print "player arrive run stand animation"
         self.enable()
 
     def isInPosition(self):
@@ -122,12 +128,7 @@ class PokerAnimationPlayer:
         pass
     
     def manageSitinSitout(self):
-#        print "##################"
-#        print "manage Sitin"
-#        print "taille de sitin %d"%len(self.sitin_stack)
-#        for i in self.sitin_stack:
-#            print "%s"%i
-#        print "----------------------------------------"
+        
         self.sitin_stack.pop(0) # remove the first element
         if len(self.sitin_stack) > 0:
             if self.sitin_stack[0] == "sitout":
@@ -142,18 +143,8 @@ class PokerAnimationPlayer:
                     self.setAnimationCallback(anim, self.manageSitinSitout)
                 else:
                     self.sitin_stack.pop()
-#        print "taille de sitin %d"%len(self.sitin_stack)
-#        for i in self.sitin_stack:
-#           print "%s"%i
-#        print "########################################"
-        
 
     def sitoutAction(self):
-#        print "########################################"
-#        print "taille de sitin %d"%len(self.sitin_stack)
-#        for i in self.sitin_stack:
-#            print "%s"%i
-#        print "----------------------------------------"
         if len(self.sitin_stack) > 0:
             if self.sitin_stack[-1]!="sitout":
                 if len(self.sitin_stack) > 1:
@@ -165,12 +156,6 @@ class PokerAnimationPlayer:
             self.sitin_stack.append("sitout")
             self.manageSitinSitout()
 
-#        print "taille de sitin %d"%len(self.sitin_stack)
-#        for i in self.sitin_stack:
-#           print "%s"%i
-#        print "########################################"
-
-            
     def lookCards(self, packet):
         pass
     
@@ -199,17 +184,6 @@ class PokerAnimationPlayer:
     def check(self):
         pass
             
-    def normalizeChips(self, game, chips):
-        chips = chips[:]
-        normalized_chips = []
-        for chip_value in game.chips_values:
-            count = chips.pop(0)
-            if count > 0:
-                normalized_chips.append(chip_value)
-                normalized_chips.append(count)
-
-        return normalized_chips
-
     def bet(self,game_id,chips):
         pass
 
@@ -221,7 +195,7 @@ class PokerAnimationPlayer:
     
     def fold(self, game_id):
         player = self.table.game.getPlayer(self.serial)
-        if self.myself and player.sit_out_next_turn:
+        if self.myself and player is not None and player.sit_out_next_turn:
             self.sitoutAction()
 
     def sitoutIfNotInGame(self):
@@ -319,13 +293,13 @@ class PokerAnimationTable:
             chips = 0
             if serial in serial2share.keys():
                 chips = serial2share[serial]
+            # a predicat check that winner are on the table when we use this packet but not the loosers
+            # so it's possible to come on a table with this packet and serials (who loose) missing in the
+            # serial list
             # to find a bug
             if serial not in self.serial2player.keys():
-                print "showdown problem on game id %d" % self.game.id
-                print "serials on table:"
-                print self.serial2player.keys()
-                print "serials from showdown packet:"
-                print serials
+                continue
+            
             player = self.serial2player[serial]
             player.showdownDelta(delta, serial2delta[serial] == delta_max, serial2delta[serial] == delta_min, chips)
             
@@ -433,6 +407,13 @@ class PokerAnimationScheduler:
         self.animation_renderer = kwargs.get("animation_renderer", None)
         self.config = kwargs.get("config", None)
         self.settings = kwargs.get("settings", None)
+        if self.config:
+            chips_values = self.config.headerGet("/sequence/chips")
+            if not chips_values:
+                raise UserWarning, "PokerAnimationScheduler: no /sequence/chips found in %s" % self.config.path
+            self.chips_values = map(int, chips_values.split())
+        else:
+            self.chips_values = [1]
         self.verbose = self.settings and int(self.settings.headerGet("/settings/@verbose")) or 0
         self.protocol = None
         self.id2table = {}
@@ -522,9 +503,6 @@ class PokerAnimationScheduler:
         tmp = protocol.callbacks['current'][PACKET_POKER_PLAYER_LEAVE]
         tmp.remove(self.playerLeave)
         tmp.insert(0, self.playerLeave)
-#        tmp = protocol.callbacks['current'][PACKET_POKER_TABLE]
-#        tmp.remove(self.table)
-#        tmp.insert(0, self.table)
         tmp = protocol.callbacks['current'][PACKET_POKER_TABLE_DESTROY]
         tmp.remove(self.tableQuit)
         tmp.insert(0, self.tableQuit)
